# frozen_string_literal: true

require "common_models/models/devices/gazebo/entity"
module CommonModels
    module Devices
        module Gazebo
            device_type "Underwater" do
                provides Entity
            end
        end
    end
end
